summaryrefslogtreecommitdiffstats
path: root/tqtinterface/qt4/src/widgets/tqscrollview.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'tqtinterface/qt4/src/widgets/tqscrollview.cpp')
-rw-r--r--tqtinterface/qt4/src/widgets/tqscrollview.cpp38
1 files changed, 19 insertions, 19 deletions
diff --git a/tqtinterface/qt4/src/widgets/tqscrollview.cpp b/tqtinterface/qt4/src/widgets/tqscrollview.cpp
index 1c43180..49c5b4d 100644
--- a/tqtinterface/qt4/src/widgets/tqscrollview.cpp
+++ b/tqtinterface/qt4/src/widgets/tqscrollview.cpp
@@ -176,7 +176,7 @@ public:
bool anyVisibleChildren();
void autoMove(TQScrollView* sv);
void autoResize(TQScrollView* sv);
- void autoResizeHint(TQScrollView* sv);
+ void autoRetqsizeHint(TQScrollView* sv);
void viewportResized( int w, int h );
TQScrollBar* hbar;
@@ -314,19 +314,19 @@ void TQScrollViewData::autoResize(TQScrollView* sv)
}
}
-void TQScrollViewData::autoResizeHint(TQScrollView* sv)
+void TQScrollViewData::autoRetqsizeHint(TQScrollView* sv)
{
if ( policy == TQScrollView::AutoOne ) {
TQSVChildRec* r = tqchildren.first();
if (r) {
- TQSize s = r->child->sizeHint();
+ TQSize s = r->child->tqsizeHint();
if ( s.isValid() )
r->child->resize(s);
}
} else if ( policy == TQScrollView::AutoOneFit ) {
TQSVChildRec* r = tqchildren.first();
if (r) {
- TQSize sh = r->child->sizeHint();
+ TQSize sh = r->child->tqsizeHint();
sh = sh.boundedTo( r->child->tqmaximumSize() );
sv->resizeContents( sh.width(), sh.height() );
}
@@ -338,7 +338,7 @@ void TQScrollViewData::viewportResized( int w, int h )
if ( policy == TQScrollView::AutoOneFit ) {
TQSVChildRec* r = tqchildren.first();
if (r) {
- TQSize sh = r->child->sizeHint();
+ TQSize sh = r->child->tqsizeHint();
sh = sh.boundedTo( r->child->tqmaximumSize() );
r->child->resize( TQMAX(w,sh.width()), TQMAX(h,sh.height()) );
}
@@ -562,12 +562,12 @@ void TQScrollViewData::viewportResized( int w, int h )
the size of that widget. Otherwise the behavior is undefined.
\value AutoOneFit if there is only one child widget the contents stays
- the size of that widget's sizeHint(). If the scrollview is resized
- larger than the child's sizeHint(), the child will be resized to
+ the size of that widget's tqsizeHint(). If the scrollview is resized
+ larger than the child's tqsizeHint(), the child will be resized to
fit. If there is more than one child, the behavior is undefined.
*/
//#### The widget will be resized to its sizeHint() when a LayoutHint event
//#### is received
/*!
@@ -794,8 +794,8 @@ TQSize TQScrollView::viewportSize( int x, int y ) const
bool needh, needv;
bool showh, showv;
- int hsbExt = horizontalScrollBar()->sizeHint().height();
- int vsbExt = verticalScrollBar()->sizeHint().width();
+ int hsbExt = horizontalScrollBar()->tqsizeHint().height();
+ int vsbExt = verticalScrollBar()->tqsizeHint().width();
if ( d->policy != AutoOne || d->anyVisibleChildren() ) {
// Do we definitely need the scrollbar?
@@ -865,8 +865,8 @@ void TQScrollView::updateScrollBars()
bool showv;
bool showc = FALSE;
- int hsbExt = horizontalScrollBar()->sizeHint().height();
- int vsbExt = verticalScrollBar()->sizeHint().width();
+ int hsbExt = horizontalScrollBar()->tqsizeHint().height();
+ int vsbExt = verticalScrollBar()->tqsizeHint().width();
TQSize oldVisibleSize( visibleWidth(), visibleHeight() );
@@ -1401,7 +1401,7 @@ void TQScrollView::addChild(TQWidget* child, int x, int y)
if (r) {
r->moveTo(this,x,y,d->clipped_viewport);
if ( d->policy > Manual ) {
- d->autoResizeHint(this);
+ d->autoRetqsizeHint(this);
d->autoResize(this); // #### better to just deal with this one widget!
}
return;
@@ -1422,7 +1422,7 @@ void TQScrollView::addChild(TQWidget* child, int x, int y)
d->addChildRec(child,x,y)->hideOrShow(this, d->clipped_viewport);
if ( d->policy > Manual ) {
- d->autoResizeHint(this);
+ d->autoRetqsizeHint(this);
d->autoResize(this); // #### better to just deal with this one widget!
}
}
@@ -1551,7 +1551,7 @@ bool TQScrollView::eventFilter( TQObject *obj, TQEvent *e )
removeChild((TQWidget*)((TQChildEvent*)e)->child());
break;
case TQEvent::LayoutHint:
- d->autoResizeHint(this);
+ d->autoRetqsizeHint(this);
break;
default:
break;
@@ -2688,7 +2688,7 @@ void TQScrollView::viewportToContents( int vx, int vy, int& x, int& y ) const
/*!
\reimp
*/
-TQSize TQScrollView::sizeHint() const
+TQSize TQScrollView::tqsizeHint() const
{
if ( d->use_cached_size_hint && d->cachedSizeHint.isValid() )
return d->cachedSizeHint;
@@ -2700,7 +2700,7 @@ TQSize TQScrollView::sizeHint() const
if ( d->policy > Manual ) {
TQSVChildRec *r = d->tqchildren.first();
if ( r ) {
- TQSize cs = r->child->sizeHint();
+ TQSize cs = r->child->tqsizeHint();
if ( cs.isValid() )
sz += cs.boundedTo( r->child->tqmaximumSize() );
else
@@ -2710,9 +2710,9 @@ TQSize TQScrollView::sizeHint() const
sz += TQSize( d->contentsWidth(), contentsHeight() );
}
if (d->vMode == AlwaysOn)
- sz.setWidth(sz.width() + d->vbar->sizeHint().width());
+ sz.setWidth(sz.width() + d->vbar->tqsizeHint().width());
if (d->hMode == AlwaysOn)
- sz.setHeight(sz.height() + d->hbar->sizeHint().height());
+ sz.setHeight(sz.height() + d->hbar->tqsizeHint().height());
return sz.expandedTo( TQSize(12 * h, 8 * h) )
.boundedTo( TQSize(36 * h, 24 * h) );
}
@@ -562,12 +562,12 @@ void TQScrollViewData::viewportResized( int w, int h )
fit. If there is more than one child, the behavior is undefined.
*/
-//#### The widget will be resized to its sizeHint() when a LayoutHint event
+//#### The widget will be resized to its tqsizeHint() when a LayoutHint event
//#### is received
/*!